@@ -4,7 +4,7 @@
     created              : Tue Oct 9 16:52:00 CET 2001
     copyright            : (C) 2001-2002 by Bernhard Wymann, some Code from Remi Coulom, K1999.cpp
     email                : berniw@bluewin.ch
-    version              : $Id: pathfinder.cpp,v 1.55 2005/02/01 18:33:32 berniw Exp $
+    version              : $Id: pathfinder.cpp,v 1.56 2007/11/06 20:43:31 torcs Exp $
 
  ***************************************************************************/
 
@@ -664,7 +664,7 @@ void Pathfinder::plan(MyCar* myc)
 #ifdef PATH_K1999
 	/* compute path */
 	for (int step = 128; (step /= 2) > 0;) {
-		for (int i = 100 * int(sqrt(step)); --i >= 0;) smooth(step);
+		for (int i = 100 * int(sqrt((double)step)); --i >= 0;) smooth(step);
 		interpolate(step);
 	}
 #endif	// PATH_K1999
