@@ -4,7 +4,7 @@
     created              : Thu Dec 20 01:21:49 CET 2002
     copyright            : (C) 2002-2004 Bernhard Wymann
     email                : berniw@bluewin.ch
-    version              : $Id: driver.cpp,v 1.14 2005/02/01 18:33:34 berniw Exp $
+    version              : $Id: driver.cpp,v 1.16.2.1 2008/05/26 20:28:07 berniw Exp $
 
  ***************************************************************************/
 
@@ -19,11 +19,7 @@
 
 #include "driver.h"
 
-#ifdef WIN32
-#define snprintf _snprintf
-#endif
-
-const float Driver::MAX_UNSTUCK_ANGLE = 15.0/180.0*PI;		// [radians] If the angle of the car on the track is smaller, we assume we are not stuck.
+const float Driver::MAX_UNSTUCK_ANGLE = 15.0f/180.0f*PI;	// [radians] If the angle of the car on the track is smaller, we assume we are not stuck.
 const float Driver::UNSTUCK_TIME_LIMIT = 2.0f;				// [s] We try to get unstuck after this time.
 const float Driver::MAX_UNSTUCK_SPEED = 5.0f;				// [m/s] Below this speed we consider being stuck.
 const float Driver::MIN_UNSTUCK_DIST = 3.0f;				// [m] If we are closer to the middle we assume to be not stuck.
@@ -55,6 +51,9 @@ const float Driver::CATCH_FACTOR = 10.0f;					// [-] select MIN(catchdist, dist*
 const float Driver::CLUTCH_FULL_MAX_TIME = 2.0f;			// [s] Time to apply full clutch.
 const float Driver::USE_LEARNED_OFFSET_RANGE = 0.2f;		// [m] if offset < this use the learned stuff
 
+const float Driver::TEAM_REAR_DIST = 50.0f;					//
+const int Driver::TEAM_DAMAGE_CHANGE_LEAD = 700;			// When to change position in the team?
+
 // Static variables.
 Cardata *Driver::cardata = NULL;
 double Driver::currentsimtime;
@@ -112,10 +111,10 @@ void Driver::initTrack(tTrack* t, void *carHandle, void **carParmHandle, tSituat
     }
 
 	// Create a pit stop strategy object.
-	strategy = new SimpleStrategy();
+	strategy = new SimpleStrategy2();
 
 	// Init fuel.
-	strategy->setFuelAtRaceStart(t, carParmHandle, s);
+	strategy->setFuelAtRaceStart(t, carParmHandle, s, INDEX);
 
 	// Load and set parameters.
 	MU_FACTOR = GfParmGetNum(*carParmHandle, BT_SECT_PRIV, BT_ATT_MUFACTOR, (char*)NULL, 0.69f);
@@ -130,11 +129,11 @@ void Driver::newRace(tCarElt* car, tSituation *s)
 	OVERTAKE_OFFSET_INC = OVERTAKE_OFFSET_SPEED*deltaTime;
 	stuck = 0;
 	alone = 1;
-	clutchtime = 0.0;
-	oldlookahead = 0.0;
+	clutchtime = 0.0f;
+	oldlookahead = 0.0f;
 	this->car = car;
-	CARMASS = GfParmGetNum(car->_carHandle, SECT_CAR, PRM_MASS, NULL, 1000.0);
-	myoffset = 0.0;
+	CARMASS = GfParmGetNum(car->_carHandle, SECT_CAR, PRM_MASS, NULL, 1000.0f);
+	myoffset = 0.0f;
 	initCa();
 	initCw();
 	initTireMu();
@@ -151,11 +150,17 @@ void Driver::newRace(tCarElt* car, tSituation *s)
 	opponents = new Opponents(s, this, cardata);
 	opponent = opponents->getOpponentPtr();
 
+	// Set team mate.
+	char *teammate = GfParmGetStr(car->_carHandle, BT_SECT_PRIV, BT_ATT_TEAMMATE, NULL);
+	if (teammate != NULL) {
+		opponents->setTeamMate(teammate);
+	}
+
 	// Initialize radius of segments.
 	radius = new float[track->nseg];
 	computeRadius(radius);
 
-	learn = new SegLearn(track);
+	learn = new SegLearn(track, s, INDEX);
 
 	// create the pit object.
 	pit = new Pit(s, this);
@@ -174,17 +179,17 @@ void Driver::drive(tSituation *s)
 	if (isStuck()) {
 		car->_steerCmd = -mycardata->getCarAngle() / car->_steerLock;
 		car->_gearCmd = -1;		// Reverse gear.
-		car->_accelCmd = 1.0;	// 100% accelerator pedal.
-		car->_brakeCmd = 0.0;	// No brakes.
-		car->_clutchCmd = 0.0;	// Full clutch (gearbox connected with engine).
+		car->_accelCmd = 1.0f;	// 100% accelerator pedal.
+		car->_brakeCmd = 0.0f;	// No brakes.
+		car->_clutchCmd = 0.0f;	// Full clutch (gearbox connected with engine).
 	} else {
 		car->_steerCmd = filterSColl(getSteer());
 		car->_gearCmd = getGear();
 		car->_brakeCmd = filterABS(filterBrakeSpeed(filterBColl(filterBPit(getBrake()))));
-		if (car->_brakeCmd == 0.0) {
+		if (car->_brakeCmd == 0.0f) {
 			car->_accelCmd = filterTCL(filterTrk(filterOverlap(getAccel())));
 		} else {
-			car->_accelCmd = 0.0;
+			car->_accelCmd = 0.0f;
   		}
 		car->_clutchCmd = getClutch();
 
@@ -206,7 +211,7 @@ int Driver::pitCommand(tSituation *s)
 // End of the current race.
 void Driver::endRace(tSituation *s)
 {
-	// Nothing at the moment.
+	// Nothing for now.
 }
 
 
@@ -219,7 +224,7 @@ void Driver::endRace(tSituation *s)
 
 void Driver::computeRadius(float *radius)
 {
-	float lastturnarc = 0.0;
+	float lastturnarc = 0.0f;
 	int lastsegtype = TR_STR;
 
 	tTrackSeg *currentseg, *startseg = track->seg;
@@ -231,15 +236,15 @@ void Driver::computeRadius(float *radius)
 			radius[currentseg->id] = FLT_MAX;
 		} else {
 			if (currentseg->type != lastsegtype) {
-				float arc = 0.0;
+				float arc = 0.0f;
 				tTrackSeg *s = currentseg;
 				lastsegtype = currentseg->type;
 
-				while (s->type == lastsegtype && arc < PI/2.0) {
+				while (s->type == lastsegtype && arc < PI/2.0f) {
 					arc += s->arc;
 					s = s->next;
 				}
-				lastturnarc = arc/(PI/2.0);
+				lastturnarc = arc/(PI/2.0f);
 			}
 			radius[currentseg->id] = (currentseg->radius + currentseg->width/2.0)/lastturnarc;
 		}
@@ -255,12 +260,21 @@ float Driver::getAllowedSpeed(tTrackSeg *segment)
 	float mu = segment->surface->kFriction*TIREMU*MU_FACTOR;
 	float r = radius[segment->id];
 	float dr = learn->getRadius(segment);
-	if ((alone > 0 && fabs(myoffset) < USE_LEARNED_OFFSET_RANGE) ||
-		dr < 0.0
+	if (dr < 0.0f) {
+		r += dr;
+	} else {
+		float tdr = dr*(1.0f - MIN(1.0f, fabs(myoffset)*2.0f/segment->width));
+		r += tdr;	
+	}
+	// README: the outcommented code is the more save version.
+	/*if ((alone > 0 && fabs(myoffset) < USE_LEARNED_OFFSET_RANGE) ||
+		dr < 0.0f
 	) {
 		r += dr;
-	}
-	return sqrt((mu*G*r)/(1.0 - MIN(1.0, r*CA*mu/mass)));
+	}*/
+	r = MAX(1.0, r);
+
+	return sqrt((mu*G*r)/(1.0f - MIN(1.0f, r*CA*mu/mass)));
 }
 
 
@@ -299,7 +313,7 @@ float Driver::filterOverlap(float accel)
 	int i;
 	for (i = 0; i < opponents->getNOpponents(); i++) {
 		if (opponent[i].getState() & OPP_LETPASS) {
-			return MIN(accel, 0.5);
+			return MIN(accel, 0.5f);
 		}
 	}
 	return accel;
@@ -317,12 +331,12 @@ float Driver::getBrake()
 		// We drive forward, normal braking.
 		tTrackSeg *segptr = car->_trkPos.seg;
 		float mu = segptr->surface->kFriction;
-		float maxlookaheaddist = currentspeedsqr/(2.0*mu*G);
+		float maxlookaheaddist = currentspeedsqr/(2.0f*mu*G);
 		float lookaheaddist = getDistToSegEnd();
 
 		float allowedspeed = getAllowedSpeed(segptr);
 		if (allowedspeed < car->_speed_x) {
-			return MIN(1.0, (car->_speed_x-allowedspeed)/(FULL_ACCEL_MARGIN));
+			return MIN(1.0f, (car->_speed_x-allowedspeed)/(FULL_ACCEL_MARGIN));
 		}
 
 		segptr = segptr->next;
@@ -330,13 +344,13 @@ float Driver::getBrake()
 			allowedspeed = getAllowedSpeed(segptr);
 			if (allowedspeed < car->_speed_x) {
 				if (brakedist(allowedspeed, mu) > lookaheaddist) {
-					return 1.0;
+					return 1.0f;
 				}
 			}
 			lookaheaddist += segptr->length;
 			segptr = segptr->next;
 		}
-		return 0.0;
+		return 0.0f;
 	}
 }
 
@@ -368,7 +382,7 @@ int Driver::getGear()
 float Driver::getSteer()
 {
 	float targetAngle;
-	v2d target = getTargetPoint();
+	vec2f target = getTargetPoint();
 
 	targetAngle = atan2(target.y - car->_pos_Y, target.x - car->_pos_X);
 	targetAngle -= car->_yaw;
@@ -381,13 +395,13 @@ float Driver::getSteer()
 float Driver::getClutch()
 {
 	if (car->_gear > 1) {
-		clutchtime = 0.0;
-		return 0.0;
+		clutchtime = 0.0f;
+		return 0.0f;
 	} else {
-		float drpm = car->_enginerpm - car->_enginerpmRedLine/2.0;
+		float drpm = car->_enginerpm - car->_enginerpmRedLine/2.0f;
 		clutchtime = MIN(CLUTCH_FULL_MAX_TIME, clutchtime);
 		float clutcht = (CLUTCH_FULL_MAX_TIME - clutchtime)/CLUTCH_FULL_MAX_TIME;
-		if (car->_gear == 1 && car->_accelCmd > 0.0) {
+		if (car->_gear == 1 && car->_accelCmd > 0.0f) {
 			clutchtime += (float) RCM_MAX_DT_ROBOTS;
 		}
 
@@ -397,13 +411,13 @@ float Driver::getClutch()
 				// Compute corresponding speed to engine rpm.
 				float omega = car->_enginerpmRedLine/car->_gearRatio[car->_gear + car->_gearOffset];
 				float wr = car->_wheelRadius(2);
-				speedr = (CLUTCH_SPEED + MAX(0.0, car->_speed_x))/fabs(wr*omega);
-				float clutchr = MAX(0.0, (1.0 - speedr*2.0*drpm/car->_enginerpmRedLine));
+				speedr = (CLUTCH_SPEED + MAX(0.0f, car->_speed_x))/fabs(wr*omega);
+				float clutchr = MAX(0.0f, (1.0f - speedr*2.0f*drpm/car->_enginerpmRedLine));
 				return MIN(clutcht, clutchr);
 			} else {
 				// For the reverse gear.
-				clutchtime = 0.0;
-				return 0.0;
+				clutchtime = 0.0f;
+				return 0.0f;
 			}
 		} else {
 			return clutcht;
@@ -412,7 +426,7 @@ float Driver::getClutch()
 }
 
 // Compute target point for steering.
-v2d Driver::getTargetPoint()
+vec2f Driver::getTargetPoint()
 {
 	tTrackSeg *seg = car->_trkPos.seg;
 	float lookahead;
@@ -451,12 +465,12 @@ v2d Driver::getTargetPoint()
 	// Compute the target point.
 	offset = myoffset = pit->getPitOffset(offset, fromstart);
 
-	v2d s;
-	s.x = (seg->vertex[TR_SL].x + seg->vertex[TR_SR].x)/2.0;
-	s.y = (seg->vertex[TR_SL].y + seg->vertex[TR_SR].y)/2.0;
+	vec2f s;
+	s.x = (seg->vertex[TR_SL].x + seg->vertex[TR_SR].x)/2.0f;
+	s.y = (seg->vertex[TR_SL].y + seg->vertex[TR_SR].y)/2.0f;
 
 	if ( seg->type == TR_STR) {
-		v2d d, n;
+		vec2f d, n;
 		n.x = (seg->vertex[TR_EL].x - seg->vertex[TR_ER].x)/seg->length;
 		n.y = (seg->vertex[TR_EL].y - seg->vertex[TR_ER].y)/seg->length;
 		n.normalize();
@@ -464,11 +478,11 @@ v2d Driver::getTargetPoint()
 		d.y = (seg->vertex[TR_EL].y - seg->vertex[TR_SL].y)/seg->length;
 		return s + d*length + offset*n;
 	} else {
-		v2d c, n;
+		vec2f c, n;
 		c.x = seg->center.x;
 		c.y = seg->center.y;
 		float arc = length/seg->radius;
-		float arcsign = (seg->type == TR_RGT) ? -1.0 : 1.0;
+		float arcsign = (seg->type == TR_RGT) ? -1.0f : 1.0f;
 		arc = arc*arcsign;
 		s = s.rotate(c, arc);
 
@@ -483,15 +497,22 @@ v2d Driver::getTargetPoint()
 float Driver::getOffset()
 {
 	int i;
-	float catchdist, mincatchdist = FLT_MAX, mindist = -1000.0;
+	float catchdist, mincatchdist = FLT_MAX, mindist = -1000.0f;
 	Opponent *o = NULL;
 
 	// Increment speed dependent.
-	float incfactor = MAX_INC_FACTOR - MIN(fabs(car->_speed_x)/MAX_INC_FACTOR, (MAX_INC_FACTOR-1.0));
+	float incfactor = MAX_INC_FACTOR - MIN(fabs(car->_speed_x)/MAX_INC_FACTOR, (MAX_INC_FACTOR - 1.0f));
 
-	// Let overlap.
+	// Let overlap or let less damaged team mate pass.
 	for (i = 0; i < opponents->getNOpponents(); i++) {
-		if (opponent[i].getState() & OPP_LETPASS) {
+		// Let the teammate with less damage overtake to use slipstreaming.
+		// The position change happens when the damage difference is greater than
+		// TEAM_DAMAGE_CHANGE_LEAD.
+		if (((opponent[i].getState() & OPP_LETPASS) && !opponent[i].isTeamMate()) ||
+			(opponent[i].isTeamMate() && (car->_dammage - opponent[i].getDamage() > TEAM_DAMAGE_CHANGE_LEAD) &&
+			(opponent[i].getDistance() > -TEAM_REAR_DIST) && (opponent[i].getDistance() < -car->_dimension_x) &&
+			car->race.laps == opponent[i].getCarPtr()->race.laps))
+		{
 			// Behind, larger distances are smaller ("more negative").
 			if (opponent[i].getDistance() > mindist) {
 				mindist = opponent[i].getDistance();
@@ -504,7 +525,7 @@ float Driver::getOffset()
 		tCarElt *ocar = o->getCarPtr();
 		float side = car->_trkPos.toMiddle - ocar->_trkPos.toMiddle;
 		float w = car->_trkPos.seg->width/WIDTHDIV-BORDER_OVERTAKE_MARGIN;
-		if (side > 0.0) {
+		if (side > 0.0f) {
 			if (myoffset < w) {
 				myoffset += OVERTAKE_OFFSET_INC*incfactor;
 			}
@@ -519,7 +540,9 @@ float Driver::getOffset()
 
 	// Overtake.
 	for (i = 0; i < opponents->getNOpponents(); i++) {
-		if (opponent[i].getState() & OPP_FRONT) {
+		if ((opponent[i].getState() & OPP_FRONT) &&
+			!(opponent[i].isTeamMate() && car->race.laps <= opponent[i].getCarPtr()->race.laps))
+		{
 			catchdist = MIN(opponent[i].getCatchDist(), opponent[i].getDistance()*CATCH_FACTOR);
 			if (catchdist < mincatchdist) {
 				mincatchdist = catchdist;
@@ -547,7 +570,7 @@ float Driver::getOffset()
 			tTrackSeg *seg = car->_trkPos.seg;
 			float length = getDistToSegEnd();
 			float oldlen, seglen = length;
-			float lenright = 0.0, lenleft = 0.0;
+			float lenright = 0.0f, lenleft = 0.0f;
 			mincatchdist = MIN(mincatchdist, DISTCUTOFF);
 
 			do {
@@ -569,15 +592,15 @@ float Driver::getOffset()
 			} while (oldlen < mincatchdist);
 
 			// If we are on a straight look for the next turn.
-			if (lenleft == 0.0 && lenright == 0.0) {
+			if (lenleft == 0.0f && lenright == 0.0f) {
 				while (seg->type == TR_STR) {
 					seg = seg->next;
 				}
 				// Assume: left or right if not straight.
 				if (seg->type == TR_LFT) {
-					lenleft = 1.0;
+					lenleft = 1.0f;
 				} else {
-					lenright = 1.0;
+					lenright = 1.0f;
 				}
 			}
 
@@ -600,7 +623,7 @@ float Driver::getOffset()
 		} else if (myoffset < -OVERTAKE_OFFSET_INC) {
 			myoffset += OVERTAKE_OFFSET_INC;
 		} else {
-			myoffset = 0.0;
+			myoffset = 0.0f;
 		}
 	}
 
@@ -667,40 +690,40 @@ bool Driver::isStuck()
 // Compute aerodynamic downforce coefficient CA.
 void Driver::initCa()
 {
-	char *WheelSect[4] = {SECT_FRNTRGTWHEEL, SECT_FRNTLFTWHEEL, SECT_REARRGTWHEEL, SECT_REARLFTWHEEL};
-	float rearwingarea = GfParmGetNum(car->_carHandle, SECT_REARWING, PRM_WINGAREA, (char*) NULL, 0.0);
-	float rearwingangle = GfParmGetNum(car->_carHandle, SECT_REARWING, PRM_WINGANGLE, (char*) NULL, 0.0);
-	float wingca = 1.23*rearwingarea*sin(rearwingangle);
+	const char *WheelSect[4] = {SECT_FRNTRGTWHEEL, SECT_FRNTLFTWHEEL, SECT_REARRGTWHEEL, SECT_REARLFTWHEEL};
+	float rearwingarea = GfParmGetNum(car->_carHandle, SECT_REARWING, PRM_WINGAREA, (char*) NULL, 0.0f);
+	float rearwingangle = GfParmGetNum(car->_carHandle, SECT_REARWING, PRM_WINGANGLE, (char*) NULL, 0.0f);
+	float wingca = 1.23f*rearwingarea*sin(rearwingangle);
 
-	float cl = GfParmGetNum(car->_carHandle, SECT_AERODYNAMICS, PRM_FCL, (char*) NULL, 0.0) +
-			   GfParmGetNum(car->_carHandle, SECT_AERODYNAMICS, PRM_RCL, (char*) NULL, 0.0);
-	float h = 0.0;
+	float cl = GfParmGetNum(car->_carHandle, SECT_AERODYNAMICS, PRM_FCL, (char*) NULL, 0.0f) +
+			   GfParmGetNum(car->_carHandle, SECT_AERODYNAMICS, PRM_RCL, (char*) NULL, 0.0f);
+	float h = 0.0f;
 	int i;
 	for (i = 0; i < 4; i++)
 		h += GfParmGetNum(car->_carHandle, WheelSect[i], PRM_RIDEHEIGHT, (char*) NULL, 0.20f);
-	h*= 1.5; h = h*h; h = h*h; h = 2.0 * exp(-3.0*h);
-	CA = h*cl + 4.0*wingca;
+	h*= 1.5f; h = h*h; h = h*h; h = 2.0f * exp(-3.0f*h);
+	CA = h*cl + 4.0f*wingca;
 }
 
 
 // Compute aerodynamic drag coefficient CW.
 void Driver::initCw()
 {
-	float cx = GfParmGetNum(car->_carHandle, SECT_AERODYNAMICS, PRM_CX, (char*) NULL, 0.0);
-	float frontarea = GfParmGetNum(car->_carHandle, SECT_AERODYNAMICS, PRM_FRNTAREA, (char*) NULL, 0.0);
-	CW = 0.645*cx*frontarea;
+	float cx = GfParmGetNum(car->_carHandle, SECT_AERODYNAMICS, PRM_CX, (char*) NULL, 0.0f);
+	float frontarea = GfParmGetNum(car->_carHandle, SECT_AERODYNAMICS, PRM_FRNTAREA, (char*) NULL, 0.0f);
+	CW = 0.645f*cx*frontarea;
 }
 
 
 // Init the friction coefficient of the the tires.
 void Driver::initTireMu()
 {
-	char *WheelSect[4] = {SECT_FRNTRGTWHEEL, SECT_FRNTLFTWHEEL, SECT_REARRGTWHEEL, SECT_REARLFTWHEEL};
+	const char *WheelSect[4] = {SECT_FRNTRGTWHEEL, SECT_FRNTLFTWHEEL, SECT_REARRGTWHEEL, SECT_REARLFTWHEEL};
 	float tm = FLT_MAX;
 	int i;
 
 	for (i = 0; i < 4; i++) {
-		tm = MIN(tm, GfParmGetNum(car->_carHandle, WheelSect[i], PRM_MU, (char*) NULL, 1.0));
+		tm = MIN(tm, GfParmGetNum(car->_carHandle, WheelSect[i], PRM_MU, (char*) NULL, 1.0f));
 	}
 	TIREMU = tm;
 }
@@ -724,8 +747,8 @@ float Driver::filterBPit(float brake)
 		RtDistToPit(car, track, &dl, &dw);
 		if (dl < PIT_BRAKE_AHEAD) {
 			float mu = car->_trkPos.seg->surface->kFriction*TIREMU*PIT_MU;
-			if (brakedist(0.0, mu) > dl) {
-				return 1.0;
+			if (brakedist(0.0f, mu) > dl) {
+				return 1.0f;
 			}
 		}
 	}
@@ -739,7 +762,7 @@ float Driver::filterBPit(float brake)
 				// Brake to pit speed limit.
 				float dist = pit->getNPitStart() - s;
 				if (brakedist(pit->getSpeedlimit(), mu) > dist) {
-					return 1.0;
+					return 1.0f;
 				}
 			} else {
 				// Hold speed limit.
@@ -751,13 +774,13 @@ float Driver::filterBPit(float brake)
 			float dist = pit->getNPitLoc() - s;
 			if (pit->isTimeout(dist)) {
 				pit->setPitstop(false);
-				return 0.0;
+				return 0.0f;
 			} else {
-				if (brakedist(0.0, mu) > dist) {
-					return 1.0;
+				if (brakedist(0.0f, mu) > dist) {
+					return 1.0f;
 				} else if (s > pit->getNPitLoc()) {
 					// Stop in the pit.
-			 		return 1.0;
+			 		return 1.0f;
 				}
 			}
 		} else {
@@ -783,7 +806,7 @@ float Driver::filterBColl(float brake)
 	for (i = 0; i < opponents->getNOpponents(); i++) {
 		if (opponent[i].getState() & OPP_COLL) {
 			if (brakedist(opponent[i].getSpeed(), mu) > opponent[i].getDistance()) {
-				return 1.0;
+				return 1.0f;
 			}
 		}
 	}
@@ -795,7 +818,7 @@ float Driver::filterBColl(float brake)
 float Driver::filterSColl(float steer)
 {
 	int i;
-	float sidedist = 0.0, fsidedist = 0.0, minsidedist = FLT_MAX;
+	float sidedist = 0.0f, fsidedist = 0.0f, minsidedist = FLT_MAX;
 	Opponent *o = NULL;
 
 	// Get the index of the nearest car (o).
@@ -820,39 +843,47 @@ float Driver::filterSColl(float steer)
 			float diffangle = ocar->_yaw - car->_yaw;
 			NORM_PI_PI(diffangle);
 			// We are near and heading toward the car.
-			if (diffangle*o->getSideDist() < 0.0) {
-				const float c = SIDECOLL_MARGIN/2.0;
+			if (diffangle*o->getSideDist() < 0.0f) {
+				const float c = SIDECOLL_MARGIN/2.0f;
 				d = d - c;
-				if (d < 0.0) {
-					d = 0.0;
+				if (d < 0.0f) {
+					d = 0.0f;
 				}
 
+				// Steer delta required to drive parallel to the opponent.
 				float psteer = diffangle/car->_steerLock;
 				myoffset = car->_trkPos.toMiddle;
 
+				// Limit myoffset to suitable limits.
 				float w = o->getCarPtr()->_trkPos.seg->width/WIDTHDIV-BORDER_OVERTAKE_MARGIN;
 				if (fabs(myoffset) > w) {
-					myoffset = (myoffset > 0.0) ? w : -w;
+					myoffset = (myoffset > 0.0f) ? w : -w;
 				}
-
-				// Who is outside?
+				
+				// On straights the car near to the middle can correct more, in turns the car inside
+				// the turn does (because if you leave the track on the turn "inside" you will skid
+				// back to the track.
 				if (car->_trkPos.seg->type == TR_STR) {
 					if (fabs(car->_trkPos.toMiddle) > fabs(ocar->_trkPos.toMiddle)) {
-						psteer = steer*(d/c) + 1.5*psteer*(1.0-d/c);
+						// Its me, I do correct not that much.
+						psteer = steer*(d/c) + 1.5f*psteer*(1.0f - d/c);
 					} else {
-						psteer = steer*(d/c) + 2.0*psteer*(1.0-d/c);
+						// Its the opponent, so I correct more.
+						psteer = steer*(d/c) + 2.0f*psteer*(1.0f - d/c);
 					}
 				} else {
+					// Who is outside, heavy corrections are less dangerous
+					// if you drive near the middle of the track.
 					float outside = car->_trkPos.toMiddle - ocar->_trkPos.toMiddle;
-					float sign = (car->_trkPos.seg->type == TR_RGT) ? 1.0 : -1.0;
-					if (outside*sign > 0.0) {
-						psteer = steer*(d/c) + 1.5*psteer*(1.0-d/c);
+					float sign = (car->_trkPos.seg->type == TR_RGT) ? 1.0f : -1.0f;
+					if (outside*sign > 0.0f) {
+						psteer = steer*(d/c) + 1.5f*psteer*(1.0f - d/c);
 					} else {
-						psteer = steer*(d/c) + 2.0*psteer*(1.0-d/c);
+						psteer = steer*(d/c) + 2.0f*psteer*(1.0f - d/c);
 					}
 				}
 
-				if (psteer*steer > 0.0 && fabs(steer) > fabs(psteer)) {
+				if (psteer*steer > 0.0f && fabs(steer) > fabs(psteer)) {
 					return steer;
 				} else {
 					return psteer;
@@ -869,11 +900,11 @@ float Driver::filterABS(float brake)
 {
 	if (car->_speed_x < ABS_MINSPEED) return brake;
 	int i;
-	float slip = 0.0;
+	float slip = 0.0f;
 	for (i = 0; i < 4; i++) {
 		slip += car->_wheelSpinVel(i) * car->_wheelRadius(i);
 	}
-	slip = car->_speed_x - slip/4.0;
+	slip = car->_speed_x - slip/4.0f;
 	if (slip > ABS_SLIP) {
 		brake = brake - MIN(brake, (slip - ABS_SLIP)/ABS_RANGE);
 	}
@@ -910,7 +941,7 @@ void Driver::initTCLfilter()
 float Driver::filterTCL_RWD()
 {
 	return (car->_wheelSpinVel(REAR_RGT) + car->_wheelSpinVel(REAR_LFT)) *
-			car->_wheelRadius(REAR_LFT) / 2.0;
+			car->_wheelRadius(REAR_LFT) / 2.0f;
 }
 
 
@@ -918,7 +949,7 @@ float Driver::filterTCL_RWD()
 float Driver::filterTCL_FWD()
 {
 	return (car->_wheelSpinVel(FRNT_RGT) + car->_wheelSpinVel(FRNT_LFT)) *
-			car->_wheelRadius(FRNT_LFT) / 2.0;
+			car->_wheelRadius(FRNT_LFT) / 2.0f;
 }
 
 
@@ -928,7 +959,7 @@ float Driver::filterTCL_4WD()
 	return ((car->_wheelSpinVel(FRNT_RGT) + car->_wheelSpinVel(FRNT_LFT)) *
 			car->_wheelRadius(FRNT_LFT) +
 		   (car->_wheelSpinVel(REAR_RGT) + car->_wheelSpinVel(REAR_LFT)) *
-			car->_wheelRadius(REAR_LFT)) / 4.0;
+			car->_wheelRadius(REAR_LFT)) / 4.0f;
 }
 
 
@@ -939,28 +970,28 @@ float Driver::filterTrk(float accel)
 
 	if (car->_speed_x < MAX_UNSTUCK_SPEED ||		// Too slow.
 		pit->getInPit() ||							// Pit stop.
-		car->_trkPos.toMiddle*speedangle > 0.0)		// Speedvector points to the inside of the turn.
+		car->_trkPos.toMiddle*speedangle > 0.0f)	// Speedvector points to the inside of the turn.
 	{
 		return accel;
 	}
 
 	if (seg->type == TR_STR) {
 		float tm = fabs(car->_trkPos.toMiddle);
-		float w = (seg->width - car->_dimension_y)/2.0 ;
+		float w = (seg->width - car->_dimension_y)/2.0f ;
 		if (tm > w) {
-			return 0.0;
+			return 0.0f;
 		} else {
 			return accel;
 		}
 	} else {
-		float sign = (seg->type == TR_RGT) ? -1.0 : 1.0;
-		if (car->_trkPos.toMiddle*sign > 0.0) {
+		float sign = (seg->type == TR_RGT) ? -1.0f : 1.0f;
+		if (car->_trkPos.toMiddle*sign > 0.0f) {
 			return accel;
 		} else {
 			float tm = fabs(car->_trkPos.toMiddle);
 			float w = seg->width/WIDTHDIV;
 			if (tm > w) {
-				return 0.0;
+				return 0.0f;
 			} else {
 				return accel;
 			}
@@ -976,6 +1007,6 @@ float Driver::brakedist(float allowedspeed, float mu)
 	float d = (CA*mu + CW)/mass;
 	float v1sqr = currentspeedsqr;
 	float v2sqr = allowedspeed*allowedspeed;
-	return -log((c + v2sqr*d)/(c + v1sqr*d))/(2.0*d);
+	return -log((c + v2sqr*d)/(c + v1sqr*d))/(2.0f*d);
 }
 
