@@ -4,7 +4,7 @@
     created              : Thu Dec 20 01:21:49 CET 2002
     copyright            : (C) 2002 Bernhard Wymann
     email                : berniw@bluewin.ch
-    version              : $Id: driver.cpp,v 1.2 2003/08/13 00:03:15 berniw Exp $
+    version              : $Id: driver.cpp,v 1.2.2.1 2008/05/31 23:27:06 berniw Exp $
 
  ***************************************************************************/
 
@@ -403,7 +403,7 @@ bool Driver::isStuck()
 /* Compute aerodynamic downforce coefficient CA */
 void Driver::initCa()
 {
-	char *WheelSect[4] = {SECT_FRNTRGTWHEEL, SECT_FRNTLFTWHEEL, SECT_REARRGTWHEEL, SECT_REARLFTWHEEL};
+	const char *WheelSect[4] = {SECT_FRNTRGTWHEEL, SECT_FRNTLFTWHEEL, SECT_REARRGTWHEEL, SECT_REARLFTWHEEL};
 	float rearwingarea = GfParmGetNum(car->_carHandle, SECT_REARWING, PRM_WINGAREA, (char*) NULL, 0.0);
 	float rearwingangle = GfParmGetNum(car->_carHandle, SECT_REARWING, PRM_WINGANGLE, (char*) NULL, 0.0);
 	float wingca = 1.23*rearwingarea*sin(rearwingangle);
@@ -431,7 +431,7 @@ void Driver::initCw()
 /* Init the friction coefficient of the the tires */
 void Driver::initTireMu()
 {
-	char *WheelSect[4] = {SECT_FRNTRGTWHEEL, SECT_FRNTLFTWHEEL, SECT_REARRGTWHEEL, SECT_REARLFTWHEEL};
+	const char *WheelSect[4] = {SECT_FRNTRGTWHEEL, SECT_FRNTLFTWHEEL, SECT_REARRGTWHEEL, SECT_REARLFTWHEEL};
 	float tm = FLT_MAX;
 	int i;
 
