@@ -4,7 +4,7 @@
     created              : Sun Jan 30 22:58:45 CET 2000
     copyright            : (C) 2000 by Eric Espie
     email                : torcs@free.fr
-    version              : $Id: graphic.h,v 1.12 2005/02/01 18:44:52 berniw Exp $
+    version              : $Id: graphic.h,v 1.14 2005/06/05 10:47:31 olethros Exp $
 
  ***************************************************************************/
 
@@ -31,8 +31,17 @@
 #define GR_SOUND_PARM_CFG			"config/sound.xml"
 #define GR_SCT_SOUND				"Sound Settings"
 #define GR_ATT_SOUND_STATE			"state"
-#define GR_ATT_SOUND_STATE_ENABLED	"enabled"
+#define GR_ATT_SOUND_STATE_PLIB     "plib"
+#define GR_ATT_SOUND_STATE_OPENAL	"openal"
 #define GR_ATT_SOUND_STATE_DISABLED	"disabled"
+#define GR_ATT_SOUND_VOLUME	        "volume"
+
+#define GR_SCT_GLFEATURES					"OpenGL Features"
+#define GR_ATT_TEXTURECOMPRESSION			"texture compression ARB"
+#define GR_ATT_TEXTURECOMPRESSION_ENABLED	"enabled"
+#define GR_ATT_TEXTURECOMPRESSION_DISABLED	"disabled"
+
+#define GR_ATT_TEXTURESIZE					"user texture sizelimit"
 
 #define GR_SCT_DISPMODE		"Display Mode"
 #define GR_ATT_CAM		"camera"
