@@ -18,7 +18,7 @@
 
      For further information visit http://plib.sourceforge.net
 
-     $Id: js.h,v 1.6 2004/10/07 17:05:04 olethros Exp $
+     $Id: js.h,v 1.6.2.1 2008/11/09 17:50:21 berniw Exp $
 */
 
 #ifndef __INCLUDED_JS_H__
@@ -28,7 +28,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h> // -dw- for memcpy
+#include <cstring>
 
 #ifdef macintosh
 #  include <InputSprocket.h>
