@@ -4,7 +4,7 @@
     created              : Wed Apr 26 20:05:12 CEST 2000
     copyright            : (C) 2000 by Eric Espie
     email                : torcs@free.fr
-    version              : $Id: driverconfig.cpp,v 1.7 2005/02/01 15:55:51 berniw Exp $
+    version              : $Id: driverconfig.cpp,v 1.7.2.1 2008/11/09 17:50:21 berniw Exp $
 
  ***************************************************************************/
 
@@ -19,7 +19,6 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <tgfclient.h>
 #include <track.h>
 #include <robot.h>
@@ -578,15 +577,16 @@ ChangeReverse(void *vdelta)
 static void
 ChangeTrans(void * /* dummy */)
 {
-    if (curPlayer == NULL) {
-	return;
-    }
-    if (curPlayer->transmission != HM_VAL_AUTO) {
-	curPlayer->transmission = HM_VAL_AUTO;
-    } else {
-	curPlayer->transmission = HM_VAL_MANUAL;
-    }
-    refreshEditVal();
+	if (curPlayer == NULL) {
+		return;
+	}
+	
+	if (strcmp(curPlayer->transmission,HM_VAL_AUTO) != 0) {
+		curPlayer->transmission = HM_VAL_AUTO;
+	} else {
+		curPlayer->transmission = HM_VAL_MANUAL;
+	}
+	refreshEditVal();
 }
 
 void *
