@@ -1,5 +1,5 @@
 // -*- Mode: c++ -*-
-// $Id: policy.cpp,v 1.6 2005/08/05 09:02:58 berniw Exp $
+// $Id: policy.cpp,v 1.7 2005/09/19 12:48:03 berniw Exp $
 
 // copyright (c) 2004 by Christos Dimitrakakis <dimitrak@idiap.ch>
 /***************************************************************************
@@ -155,7 +155,7 @@ void DiscretePolicy::saveState(FILE* f)
 DiscretePolicy::~DiscretePolicy()
 {
 	real sum = 0.0;
-	FILE* f = fopen ("/tmp/discrete","w");
+	FILE* f = fopen ("/tmp/discrete","wb");
 
 	int s;
 	for (s=0; s<n_states; s++) {
@@ -484,7 +484,7 @@ void DiscretePolicy::Reset ()
 void DiscretePolicy::loadFile (char* f)
 {
 	FILE* fh = NULL;
-	fh = fopen (f, "r");
+	fh = fopen (f, "rb");
 	if (fh==NULL) {
 		fprintf (stderr, "Failed to read file %s\n", f);
 		return;
@@ -549,7 +549,7 @@ void DiscretePolicy::loadFile (char* f)
 /// Save policy to a file.
 void DiscretePolicy::saveFile (char* f) {
 	FILE* fh = NULL;
-	fh = fopen (f, "w");
+	fh = fopen (f, "wb");
 	if (fh==NULL) {
 		fprintf (stderr, "Failed to write to file %s\n", f);
 		return;
