@@ -4,7 +4,7 @@
     created     : Sat Nov 23 09:05:23 CET 2002
     copyright   : (C) 2002 by Eric Espié 
     email       : eric.espie@torcs.org 
-    version     : $Id: raceengine.cpp,v 1.18 2006/02/22 22:10:14 berniw Exp $
+    version     : $Id: raceengine.cpp,v 1.19 2007/11/06 20:43:32 torcs Exp $
 
  ***************************************************************************/
 
@@ -20,7 +20,7 @@
 /** @file   
     		
     @author	<a href=mailto:eric.espie@torcs.org>Eric Espie</a>
-    @version	$Id: raceengine.cpp,v 1.18 2006/02/22 22:10:14 berniw Exp $
+    @version	$Id: raceengine.cpp,v 1.19 2007/11/06 20:43:32 torcs Exp $
 */
 
 #include <stdlib.h>
@@ -57,7 +57,7 @@ ReUpdtPitTime(tCarElt *car)
 
 	switch (car->_pitStopType) {
 		case RM_PIT_REPAIR:
-			info->totalPitTime = 2.0f + fabs(car->_pitFuel) / 8.0f + (tdble)(fabs(car->_pitRepair)) * 0.007f;
+			info->totalPitTime = 2.0f + fabs((double)(car->_pitFuel)) / 8.0f + (tdble)(fabs((double)(car->_pitRepair))) * 0.007f;
 			car->_scheduledEventTime = s->currentTime + info->totalPitTime;
 			ReInfo->_reSimItf.reconfig(car);
 			for (i=0; i<4; i++) {
