@@ -4,7 +4,7 @@
     created              : Sat Aug 14 23:03:22 CEST 1999
     copyright            : (C) 1999 by Eric Espie                         
     email                : torcs@free.fr   
-    version              : $Id: rttrack.cpp,v 1.20 2005/07/19 19:57:54 berniw Exp $                                  
+    version              : $Id: rttrack.cpp,v 1.21 2005/12/27 02:57:58 olethros Exp $                                  
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,7 +19,7 @@
 /** @file	
     		This is a collection of useful functions for programming a robot.
     @author	<a href=mailto:torcs@free.fr>Eric Espie</a>
-    @version	$Id: rttrack.cpp,v 1.20 2005/07/19 19:57:54 berniw Exp $
+    @version	$Id: rttrack.cpp,v 1.21 2005/12/27 02:57:58 olethros Exp $
     @ingroup	robottools
 */
 
@@ -398,10 +398,13 @@ RtTrackHeightL(tTrkLocPos *p)
     tdble	lg;
     tdble	tr = p->toRight;
     tTrackSeg	*seg = p->seg;
-
+    bool left_side = true;
     if ((tr < 0) && (seg->rside != NULL)) {
+        left_side = false;
+
 	seg = seg->rside;
  	tr += seg->width;
+
 	if ((tr < 0) && (seg->rside != NULL)) {
 	    seg = seg->rside;
 	    tr += RtTrackGetWidth(seg, p->toStart);
@@ -424,14 +427,24 @@ RtTrackHeightL(tTrkLocPos *p)
 	break;
     }
     if (seg->style == TR_CURB) {
+        // The final height = starting height + height difference due
+        // to track angle + height difference due to curb (this seems
+        // to be the way it is implemented in the graphics too: the
+        // curb does not adding an angle to the main track, but a
+        // height in global coords).
 	if (seg->type2 == TR_RBORDER) {
-	    return seg->vertex[TR_SR].z + p->toStart * seg->Kzl +
-		(seg->width - tr) * tan(seg->angle[TR_XS] + p->toStart * seg->Kzw + atan2(seg->height, seg->width)) +
-		seg->surface->kRoughness * sin(seg->surface->kRoughWaveLen * lg) * (seg->width - tr) / seg->width;
+            // alpha shows how far we've moved into this segment.
+            tdble alpha = seg->width - tr;
+            tdble angle = seg->angle[TR_XS] + p->toStart * seg->Kzw;
+            tdble noise = seg->surface->kRoughness * sin(seg->surface->kRoughWaveLen * lg) * alpha / seg->width;
+            tdble start_height = seg->vertex[TR_SR].z + p->toStart * seg->Kzl;
+            return start_height + tr * tan(angle) + alpha * atan2(seg->height, seg->width) + noise;
+
 	}
 	
 	return seg->vertex[TR_SR].z + p->toStart * seg->Kzl +
-	    tr * tan(seg->angle[TR_XS] + p->toStart * seg->Kzw + atan2(seg->height, seg->width)) +
+	    tr * (tan(seg->angle[TR_XS] + p->toStart * seg->Kzw)
+                  + atan2(seg->height, seg->width)) +
 	    seg->surface->kRoughness * sin(seg->surface->kRoughWaveLen * lg) * tr / seg->width;
     }
     
