@@ -1,10 +1,10 @@
 /***************************************************************************
-                 params.cpp -- configuration parameters management                                     
+                 params.cpp -- configuration parameters management
                              -------------------                                         
     created              : Fri Aug 13 22:27:57 CEST 1999
-    copyright            : (C) 1999 by Eric Espie                         
+    copyright            : (C) 1999 by Eric Espie
     email                : torcs@free.fr   
-    version              : $Id: params.cpp,v 1.28 2005/02/01 15:55:54 berniw Exp $                                  
+    version              : $Id: params.cpp,v 1.30.2.3 2008/11/09 17:50:22 berniw Exp $
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,13 +19,12 @@
 /** @file
     		This is the parameters manipulation API.
     @author	<a href=mailto:torcs@free.fr>Eric Espie</a>
-    @version	$Id: params.cpp,v 1.28 2005/02/01 15:55:54 berniw Exp $
+    @version	$Id: params.cpp,v 1.30.2.3 2008/11/09 17:50:22 berniw Exp $
     @ingroup	params
 */
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <string.h>
 #include <sys/stat.h>
 #ifndef _WIN32
 #include <unistd.h>
@@ -136,17 +135,17 @@ GF_TAILQ_HEAD (parmHead, struct parmHandle);
 
 static struct parmHead	parmHandleList;
 
-static char *getFullName(char *sectionName, const char *paramName);
-static struct param *getParamByName (struct parmHeader *conf, char *sectionName, const char *paramName, int flag);
+static char *getFullName(const char *sectionName, const char *paramName);
+static struct param *getParamByName (struct parmHeader *conf, const char *sectionName, const char *paramName, int flag);
 static void removeParamByName (struct parmHeader *conf, char *sectionName, char *paramName);
 static void removeParam (struct parmHeader *conf, struct section *section, struct param *param);
 static struct param *addParam (struct parmHeader *conf, struct section *section, const char *paramName, const char *value);
 static void removeSection (struct parmHeader *conf, struct section *section);
-static struct section *addSection (struct parmHeader *conf, char *sectionName);
+static struct section *addSection (struct parmHeader *conf, const char *sectionName);
 static void parmClean (struct parmHeader *conf);
 static void parmReleaseHandle (struct parmHandle *parmHandle);
 static void parmReleaseHeader (struct parmHeader *conf);
-static struct section *getParent (struct parmHeader *conf, char *sectionName);
+static struct section *getParent (struct parmHeader *conf, const char *sectionName);
 static void cleanUnusedSection (struct parmHeader *conf, struct section *section);
 
 
@@ -177,23 +176,23 @@ GfParmShutdown (void)
 /* Compute parameter full name           */
 /* Caller must release the returned name */
 static char *
-getFullName (char *sectionName, const char *paramName)
+getFullName (const char *sectionName, const char *paramName)
 {
-    char		*fullName;
-
-    fullName = (char *) malloc (strlen (sectionName) + strlen (paramName) + 2);
-    if (!fullName) {
-	GfError ("getFullName: malloc (%d) failed", strlen (sectionName) + strlen (paramName) + 2);
-	return NULL;
-    }
-    sprintf (fullName, "%s/%s", sectionName, paramName);
-
-    return fullName;
+	char *fullName;
+	
+	fullName = (char *) malloc (strlen (sectionName) + strlen (paramName) + 2);
+	if (!fullName) {
+		GfError ("getFullName: malloc (%d) failed", strlen (sectionName) + strlen (paramName) + 2);
+		return NULL;
+	}
+	sprintf (fullName, "%s/%s", sectionName, paramName);
+	
+	return fullName;
 }
 
 /* Get a parameter by section/param names */
 static struct param *
-getParamByName (struct parmHeader *conf, char *sectionName, const char *paramName, int flag)
+getParamByName (struct parmHeader *conf, const char *sectionName, const char *paramName, int flag)
 {
 	char *fullName;
 	struct param *param;
@@ -296,57 +295,59 @@ removeParam (struct parmHeader *conf, struct section *section, struct param *par
 static struct param *
 addParam (struct parmHeader *conf, struct section *section, const char *paramName, const char *value)
 {
-    char		*fullName;
-    struct param	*param = NULL;
-    char		*tmpVal = NULL;
+	char		*fullName;
+	struct param	*param = NULL;
+	char		*tmpVal = NULL;
+	
+	tmpVal = strdup (value);
+	if (!tmpVal) {
+		GfError ("addParam: strdup (%s) failed\n", value);
+		goto bailout;
+	}
+	
+	param = (struct param *) calloc (1, sizeof (struct param));
+	if (!param) {
+		GfError ("addParam: calloc (1, %d) failed\n", sizeof (struct param));
+		goto bailout;
+	}
 
-    tmpVal = strdup (value);
-    if (!tmpVal) {
-	GfError ("addParam: strdup (%s) failed\n", value);
-	goto bailout;
-    }
+	param->name = strdup (paramName);
+	if (!param->name) {
+		GfError ("addParam: strdup (%s) failed\n", paramName);
+		goto bailout;
+	}
+	
+	fullName = getFullName (section->fullName, paramName);
+	if (!fullName) {
+		GfError ("addParam: getFullName failed\n");
+		goto bailout;
+	}
 
-    param = (struct param *) calloc (1, sizeof (struct param));
-    if (!param) {
-	GfError ("addParam: calloc (1, %d) failed\n", sizeof (struct param));
-	goto bailout;
-    }
-    param->name = strdup (paramName);
-    if (!param->name) {
-	GfError ("addParam: strdup (%s) failed\n", paramName);
-	goto bailout;
-    }
-
-    fullName = getFullName (section->fullName, paramName);
-    if (!fullName) {
-	GfError ("addParam: getFullName failed\n");
-	goto bailout;
-    }
-    param->fullName = fullName;
-    if (GfHashAddStr (conf->paramHash, param->fullName, param)) {
-	goto bailout;
-    }
-
-    GF_TAILQ_INIT (&(param->withinList));
-
-    /* Attach to section */
-    GF_TAILQ_INSERT_TAIL (&(section->paramList), param, linkParam);
-
-    freez (param->value);
-    param->value = tmpVal;
-
-    return param;
-
- bailout:
-    if (param) {
-	freez (param->name);
-	freez (param->fullName);
+	param->fullName = fullName;
+	if (GfHashAddStr (conf->paramHash, param->fullName, param)) {
+		goto bailout;
+	}
+	
+	GF_TAILQ_INIT (&(param->withinList));
+	
+	/* Attach to section */
+	GF_TAILQ_INSERT_TAIL (&(section->paramList), param, linkParam);
+	
 	freez (param->value);
-	free  (param);
-    }
-    freez (tmpVal);
-
-    return NULL;
+	param->value = tmpVal;
+	
+	return param;
+	
+ bailout:
+	if (param) {
+		freez (param->name);
+		freez (param->fullName);
+		freez (param->value);
+		free  (param);
+	}
+	freez (tmpVal);
+	
+	return NULL;
 }
 
 
@@ -375,83 +376,84 @@ removeSection (struct parmHeader *conf, struct section *section)
 
 /* Get or create parent section */
 static struct section *
-getParent (struct parmHeader *conf, char *sectionName)
+getParent (struct parmHeader *conf, const char *sectionName)
 {
-    struct section	*section;
-    char		*tmpName;
-    char		*s;
+	struct section	*section;
+	char		*tmpName;
+	char		*s;
 
-    tmpName = strdup (sectionName);
-    if (!tmpName) {
-	GfError ("getParent: strdup (\"%s\") failed\n", sectionName);
-	return NULL;
-    }
-    s = strrchr (tmpName, '/');
-    if (s) {
-	*s = '\0';
-	section = (struct section *)GfHashGetStr (conf->sectionHash, tmpName);
-	if (section) {
-	    goto end;
+	tmpName = strdup (sectionName);
+	if (!tmpName) {
+		GfError ("getParent: strdup (\"%s\") failed\n", sectionName);
+		return NULL;
 	}
-	section = addSection (conf, tmpName);
-	goto end;
-    } else {
-	section = conf->rootSection;
-	goto end;
-    }
 
- end:
-    free (tmpName);
-    return section;
+	s = strrchr (tmpName, '/');
+	if (s) {
+		*s = '\0';
+		section = (struct section *)GfHashGetStr (conf->sectionHash, tmpName);
+		if (section) {
+			goto end;
+		}
+		section = addSection (conf, tmpName);
+		goto end;
+	} else {
+		section = conf->rootSection;
+		goto end;
+	}
+
+end:
+	free (tmpName);
+	return section;
 }
 
 /* Add a new section */
 static struct section *
-addSection (struct parmHeader *conf, char *sectionName)
+addSection (struct parmHeader *conf, const char *sectionName)
 {
-    struct section	*section;
-    struct section	*parent;
+	struct section	*section;
+	struct section	*parent;
 
-    if (GfHashGetStr (conf->sectionHash, sectionName)) {
-	GfError ("addSection: duplicate section [%s]\n", sectionName);
+	if (GfHashGetStr (conf->sectionHash, sectionName)) {
+		GfError ("addSection: duplicate section [%s]\n", sectionName);
+		return NULL;
+	}
+
+	parent = getParent(conf, sectionName);
+	if (!parent) {
+		GfError ("addSection: Problem with getParent for section [%s]\n", sectionName);
+		return NULL;
+	}
+
+	section = (struct section *) calloc (1, sizeof (struct section));
+	if (!section) {
+		GfError ("addSection: calloc (1, %d) failed\n", sizeof (struct section));
+		return NULL;
+	}
+
+	section->fullName = strdup(sectionName);
+	if (!section->fullName) {
+		GfError ("addSection: strdup (%s) failed\n", sectionName);
+		goto bailout;
+	}
+
+	if (GfHashAddStr (conf->sectionHash, sectionName, section)) {
+		GfError ("addSection: GfHashAddStr failed\n");
+		goto bailout;
+	}
+
+	/* no more bailout call */
+	section->parent = parent;
+	GF_TAILQ_INIT (&(section->paramList));
+	GF_TAILQ_INIT (&(section->subSectionList));
+	GF_TAILQ_INSERT_TAIL (&(parent->subSectionList), section, linkSection);
+
+	return section;
+
+bailout:
+	freez (section->fullName);
+	freez (section);
 	return NULL;
-    }
-
-    parent = getParent(conf, sectionName);
-    if (!parent) {
-	GfError ("addSection: Problem with getParent for section [%s]\n", sectionName);
-	return NULL;
-    }
-
-    section = (struct section *) calloc (1, sizeof (struct section));
-    if (!section) {
-	GfError ("addSection: calloc (1, %d) failed\n", sizeof (struct section));
-	return NULL;
-    }
-
-    section->fullName = strdup(sectionName);
-    if (!section->fullName) {
-	GfError ("addSection: strdup (%s) failed\n", sectionName);
-	goto bailout;
-    }
-
-    if (GfHashAddStr (conf->sectionHash, sectionName, section)) {
-	GfError ("addSection: GfHashAddStr failed\n");
-	goto bailout;
-    }
-
-    /* no more bailout call */
-    section->parent = parent;
-    GF_TAILQ_INIT (&(section->paramList));
-    GF_TAILQ_INIT (&(section->subSectionList));
-    GF_TAILQ_INSERT_TAIL (&(parent->subSectionList), section, linkSection);
-
-    return section;
-
- bailout:
-    freez (section->fullName);
-    freez (section);
-    return NULL;
 }
 
 static struct parmHeader *
@@ -1093,6 +1095,34 @@ GfParmReadFile (const char *file, int mode)
     return NULL;
 }
 
+
+
+static char* handleEntities(char *s, const char* val)
+{
+	int i = 0;
+	int len = strlen(val);
+	for (i = 0; i < len; i++) {
+		switch (val[i]) {
+			case '<':
+				s += sprintf(s, "&lt;"); break;
+			case '>':
+				s += sprintf(s, "&gt;"); break;
+			case '&':
+				s += sprintf(s, "&amp;"); break;
+			case '\'':
+				s += sprintf(s, "&apos;"); break;
+			case '"':
+				s += sprintf(s, "&quot;"); break;	
+			default:
+				*(s++) = val[i]; 
+				break;
+		}
+	}
+
+	return s;	
+}
+
+
 /**
  *	@image html output-state.png
  */
@@ -1104,7 +1134,7 @@ xmlGetOuputLine (struct parmHandle *parmHandle, char *buffer, int /* size */)
     struct section	*curSection;
     struct param	*curParam;
     struct within	*curWithin;
-    char		*s;
+    char		*s, *t;
 
     while (1) {
 	switch (outCtrl->state) {
@@ -1150,61 +1180,70 @@ xmlGetOuputLine (struct parmHandle *parmHandle, char *buffer, int /* size */)
 	    return 1;
 
 	case 4:			/* Parse section attributes list */
-	    outCtrl->curParam = GF_TAILQ_FIRST (&(outCtrl->curSection->paramList));
-	    s = strrchr (outCtrl->curSection->fullName, '/');
-	    if (!s) {
-		s = outCtrl->curSection->fullName;
-	    } else {
-		s++;
-	    }
-	    sprintf (buffer, "%s<section name=\"%s\">\n", outCtrl->indent, s);
-	    sprintf (outCtrl->indent + strlen (outCtrl->indent), "  ");
-	    outCtrl->state = 5;
-	    return 1;
+		outCtrl->curParam = GF_TAILQ_FIRST (&(outCtrl->curSection->paramList));
+		s = strrchr (outCtrl->curSection->fullName, '/');
+		if (!s) {
+			s = outCtrl->curSection->fullName;
+		} else {
+			s++;
+		}
+		
+		t = buffer;
+		t += sprintf(t, "%s<section name=\"", outCtrl->indent);
+		t = handleEntities(t, s);
+		t += sprintf (t, "\">\n");
+
+		sprintf (outCtrl->indent + strlen (outCtrl->indent), "  ");
+		outCtrl->state = 5;
+		return 1;
 
 	case 5:			/* Parse one attribute */
 	    if (!outCtrl->curParam) {
-		outCtrl->state = 6;
-		break;
-	    }
-	    curParam = outCtrl->curParam;
-	    if (curParam->type == P_STR) {
-		s = buffer;
-		s += sprintf (s, "%s<attstr name=\"%s\"", outCtrl->indent, curParam->name);
-		curWithin = GF_TAILQ_FIRST (&(curParam->withinList));
-		if (curWithin) {
-		    s += sprintf (s, " in=\"%s", curWithin->val);
-		    while ((curWithin = GF_TAILQ_NEXT (curWithin, linkWithin)) != NULL) {
-			s += sprintf (s, ",%s", curWithin->val);
-		    }
-		    s += sprintf (s, "\"");
+			outCtrl->state = 6;
+			break;
 		}
-		sprintf (s, " val=\"%s\"/>\n", curParam->value);
-		outCtrl->curParam = GF_TAILQ_NEXT (curParam, linkParam);
-		return 1;
 
+		curParam = outCtrl->curParam;
+		if (curParam->type == P_STR) {
+			s = buffer;
+			s += sprintf (s, "%s<attstr name=\"%s\"", outCtrl->indent, curParam->name);
+			curWithin = GF_TAILQ_FIRST (&(curParam->withinList));
+			if (curWithin) {
+				s += sprintf (s, " in=\"%s", curWithin->val);
+				while ((curWithin = GF_TAILQ_NEXT (curWithin, linkWithin)) != NULL) {
+					s += sprintf (s, ",%s", curWithin->val);
+				}
+				s += sprintf (s, "\"");
+			}
+
+			s += sprintf(s, " val=\"");
+			s = handleEntities(s, curParam->value);
+			s += sprintf (s, "\"/>\n");
+
+			outCtrl->curParam = GF_TAILQ_NEXT (curParam, linkParam);
+			return 1;			
 	    } else {
 
-		s = buffer;
-		s += sprintf (s, "%s<attnum name=\"%s\"", outCtrl->indent, curParam->name);
-		if (curParam->unit) {
-		    if ((curParam->min != curParam->valnum) || (curParam->max != curParam->valnum)) {
-			s += sprintf (s, " min=\"%g\" max=\"%g\"", 
-				       GfParmSI2Unit (curParam->unit, curParam->min),
-				       GfParmSI2Unit (curParam->unit, curParam->max));
-		    }
-		    s += sprintf (s, " unit=\"%s\" val=\"%g\"/>\n",
-				   curParam->unit, GfParmSI2Unit (curParam->unit, curParam->valnum));
-		} else {
-		    if ((curParam->min != curParam->valnum) || (curParam->max != curParam->valnum)) {
-			s += sprintf (s, " min=\"%g\" max=\"%g\"", 
-				       curParam->min, curParam->max);
-		    }
-		    s += sprintf (s, " val=\"%g\"/>\n", curParam->valnum);
-		}
-
-		outCtrl->curParam = GF_TAILQ_NEXT (curParam, linkParam);
-		return 1;
+			s = buffer;
+			s += sprintf (s, "%s<attnum name=\"%s\"", outCtrl->indent, curParam->name);
+			if (curParam->unit) {
+				if ((curParam->min != curParam->valnum) || (curParam->max != curParam->valnum)) {
+					s += sprintf (s, " min=\"%g\" max=\"%g\"", 
+						GfParmSI2Unit (curParam->unit, curParam->min),
+						GfParmSI2Unit (curParam->unit, curParam->max));
+				}
+				s += sprintf (s, " unit=\"%s\" val=\"%g\"/>\n",
+					curParam->unit, GfParmSI2Unit (curParam->unit, curParam->valnum));
+			} else {
+				if ((curParam->min != curParam->valnum) || (curParam->max != curParam->valnum)) {
+					s += sprintf (s, " min=\"%g\" max=\"%g\"", 
+						curParam->min, curParam->max);
+				}
+				s += sprintf (s, " val=\"%g\"/>\n", curParam->valnum);
+			}
+	
+			outCtrl->curParam = GF_TAILQ_NEXT (curParam, linkParam);
+			return 1;
 	    }
 
 	case 6:			/* Parse sub-section list */
@@ -1571,49 +1610,50 @@ evalUnit (char *unit, tdble *dest, int flg)
     @see	GfParmSI2Unit
  */
 tdble
-GfParmUnit2SI (char *unit, tdble val)
+GfParmUnit2SI (const char *unit, tdble val)
 {
-    char buf[256];
-    int  idx;
-    char *s;
-    int  inv;
-    tdble dest = val;
-    
-    if ((unit == NULL) || (strlen(unit) == 0)) return dest;
-
-    s = unit;
-    buf[0] = 0;
-    inv = 0;
-    idx = 0;
-    
-    while (*s != 0) {
-	switch (*s) {
-	case '.':
-	    evalUnit(buf, &dest, inv);
-	    buf[0] = 0;
-	    idx = 0;
-	    break;
-	case '/':
-	    evalUnit(buf, &dest, inv);
-	    buf[0] = 0;
-	    idx = 0;
-	    inv = 1;
-	    break;
-	case '2':
-	    evalUnit(buf, &dest, inv);
-	    evalUnit(buf, &dest, inv);
-	    buf[0] = 0;
-	    idx = 0;
-	    break;	    
-	default:
-	    buf[idx++] = *s;
-	    buf[idx] = 0;
-	    break;
+	char buf[256];
+	int  idx;
+	const char *s;
+	int  inv;
+	tdble dest = val;
+	
+	if ((unit == NULL) || (strlen(unit) == 0)) return dest;
+	
+	s = unit;
+	buf[0] = 0;
+	inv = 0;
+	idx = 0;
+	
+	while (*s != 0) {
+		switch (*s) {
+			case '.':
+				evalUnit(buf, &dest, inv);
+				buf[0] = 0;
+				idx = 0;
+				break;
+			case '/':
+				evalUnit(buf, &dest, inv);
+				buf[0] = 0;
+				idx = 0;
+				inv = 1;
+				break;
+			case '2':
+				evalUnit(buf, &dest, inv);
+				evalUnit(buf, &dest, inv);
+				buf[0] = 0;
+				idx = 0;
+				break;	    
+			default:
+				buf[idx++] = *s;
+				buf[idx] = 0;
+				break;
+		}
+		s++;
 	}
-	s++;
-    }
-    evalUnit(buf, &dest, inv);
-    return dest;
+
+	evalUnit(buf, &dest, inv);
+	return dest;
 }
 
 /** Convert a value in SI to "units".
@@ -1624,49 +1664,50 @@ GfParmUnit2SI (char *unit, tdble val)
     @see	GfParmUnit2SI
  */
 tdble
-GfParmSI2Unit (char *unit, tdble val)
+GfParmSI2Unit (const char *unit, tdble val)
 {
-    char buf[256];
-    int  idx;
-    char *s;
-    int  inv;
-    tdble dest = val;
-    
-    if ((unit == NULL) || (strlen(unit) == 0)) return dest;
-
-    s = unit;
-    buf[0] = 0;
-    inv = 1;
-    idx = 0;
-    
-    while (*s != 0) {
-	switch (*s) {
-	case '.':
-	    evalUnit(buf, &dest, inv);
-	    buf[0] = 0;
-	    idx = 0;
-	    break;
-	case '/':
-	    evalUnit(buf, &dest, inv);
-	    buf[0] = 0;
-	    idx = 0;
-	    inv = 0;
-	    break;
-	case '2':
-	    evalUnit(buf, &dest, inv);
-	    evalUnit(buf, &dest, inv);
-	    buf[0] = 0;
-	    idx = 0;
-	    break;	    
-	default:
-	    buf[idx++] = *s;
-	    buf[idx] = 0;
-	    break;
+	char buf[256];
+	int  idx;
+	const char *s;
+	int  inv;
+	tdble dest = val;
+	
+	if ((unit == NULL) || (strlen(unit) == 0)) return dest;
+	
+	s = unit;
+	buf[0] = 0;
+	inv = 1;
+	idx = 0;
+	
+	while (*s != 0) {
+		switch (*s) {
+			case '.':
+				evalUnit(buf, &dest, inv);
+				buf[0] = 0;
+				idx = 0;
+				break;
+			case '/':
+				evalUnit(buf, &dest, inv);
+				buf[0] = 0;
+				idx = 0;
+				inv = 0;
+				break;
+			case '2':
+				evalUnit(buf, &dest, inv);
+				evalUnit(buf, &dest, inv);
+				buf[0] = 0;
+				idx = 0;
+				break;	    
+			default:
+				buf[idx++] = *s;
+				buf[idx] = 0;
+				break;
+		}
+		s++;
 	}
-	s++;
-    }
-    evalUnit(buf, &dest, inv);
-    return dest;
+
+	evalUnit(buf, &dest, inv);
+	return dest;
 }
 
 
@@ -1901,7 +1942,7 @@ GfParmListGetCurEltName (void *handle, char *path)
     		produce incoherent pointer.
 */
 char *
-GfParmGetStr (void *parmHandle, char *path, char *key, char *deflt)
+GfParmGetStr (void *parmHandle, const char *path, const char *key, char *deflt)
 {
 	struct param *param;
 	struct parmHandle *handle = (struct parmHandle *)parmHandle;
@@ -1970,26 +2011,26 @@ GfParmGetCurStr (void *handle, char *path, char *key, char *deflt)
     @return	parameter value
  */
 tdble
-GfParmGetNum (void *handle, char *path, char *key, char *unit, tdble deflt)
+GfParmGetNum (void *handle, const char *path, const char *key, const char *unit, tdble deflt)
 {
-    struct parmHandle	*parmHandle = (struct parmHandle *)handle;
-    struct parmHeader	*conf = parmHandle->conf;
-    struct param	*param;
+	struct parmHandle	*parmHandle = (struct parmHandle *)handle;
+	struct parmHeader	*conf = parmHandle->conf;
+	struct param	*param;
 
-    if (parmHandle->magic != PARM_MAGIC) {
-	GfFatal ("GfParmGetNum: bad handle (%p)\n", parmHandle);
-	return deflt;
-    }
+	if (parmHandle->magic != PARM_MAGIC) {
+		GfFatal ("GfParmGetNum: bad handle (%p)\n", parmHandle);
+		return deflt;
+	}
 
-    param = getParamByName (conf, path, key, 0);
-    if (!param ||  (param->type != P_NUM)) {
-	return deflt;
-    }
+	param = getParamByName (conf, path, key, 0);
+	if (!param ||  (param->type != P_NUM)) {
+		return deflt;
+	}
 
-    if (unit) {
-	return GfParmSI2Unit(unit, param->valnum);
-    }
-    return  param->valnum;
+	if (unit) {
+		return GfParmSI2Unit(unit, param->valnum);
+	}
+	return  param->valnum;
 }
 
 
@@ -2132,33 +2173,34 @@ GfParmSetCurStr(void *handle, char *path, char *key, char *val)
     @warning	The key is created is necessary
  */
 int
-GfParmSetNum(void *handle, char *path, char *key, char *unit, tdble val)
+GfParmSetNum(void *handle, const char *path, const char *key, const char *unit, tdble val)
 {
-    struct parmHandle	*parmHandle = (struct parmHandle *)handle;
-    struct parmHeader	*conf = parmHandle->conf;
-    struct param	*param;
+	struct parmHandle	*parmHandle = (struct parmHandle *)handle;
+	struct parmHeader	*conf = parmHandle->conf;
+	struct param	*param;
+	
+	if (parmHandle->magic != PARM_MAGIC) {
+		GfFatal ("GfParmSetNum: bad handle (%p)\n", parmHandle);
+		return -1;
+	}
+	
+	param = getParamByName (conf, path, key, PARAM_CREATE);
+	if (!param) {
+		return -11;
+	}
 
-    if (parmHandle->magic != PARM_MAGIC) {
-	GfFatal ("GfParmSetNum: bad handle (%p)\n", parmHandle);
-	return -1;
-    }
-
-    param = getParamByName (conf, path, key, PARAM_CREATE);
-    if (!param) {
-	return -11;
-    }
-    param->type = P_NUM;
-    FREEZ (param->unit);
-    if (unit) {
-	param->unit = strdup (unit);
-    }
-
-    val = GfParmUnit2SI (unit, val);
-    param->valnum = val;
-    param->min = val;
-    param->max = val;
-
-    return 0;
+	param->type = P_NUM;
+	FREEZ (param->unit);
+	if (unit) {
+		param->unit = strdup (unit);
+	}
+	
+	val = GfParmUnit2SI (unit, val);
+	param->valnum = val;
+	param->min = val;
+	param->max = val;
+	
+	return 0;
 }
 
 /** Set a numerical parameter in a config file.
