@@ -4,7 +4,7 @@
     created              : Fri Aug 13 22:01:33 CEST 1999
     copyright            : (C) 1999 by Eric Espie                         
     email                : torcs@free.fr   
-    version              : $Id: gui.cpp,v 1.7 2006/10/06 14:13:55 berniw Exp $                                  
+    version              : $Id: gui.cpp,v 1.7.2.3 2008/11/09 17:50:22 berniw Exp $                                  
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,13 +19,12 @@
 /** @file
     		This API is used to manage all the menu screens.
     @author	<a href=mailto:torcs@free.fr>Eric Espie</a>
-    @version	$Id: gui.cpp,v 1.7 2006/10/06 14:13:55 berniw Exp $
+    @version	$Id: gui.cpp,v 1.7.2.3 2008/11/09 17:50:22 berniw Exp $
     @ingroup	gui
 */
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <string.h>
 #include <time.h>
 
 #include <tgfclient.h>
@@ -163,16 +162,34 @@ GfuiDisplay(void)
 	}
 	
 	if (GfuiScreen->bgImage != 0) {
+		GLfloat tx1 = 0.0f, tx2 = 1.0f, ty1 = 0.0f, ty2 = 1.0f;
+		
+		// All background images are 16:10 images which are stored as quadratic images.
+		// Compute texture coordinates to ensure proper unskewed/unstretched display of
+		// image content.
+		tdble rfactor = (16.0f*ViewH)/(10.0f*ViewW);
+		if (rfactor >= 1.0f) {
+			// Aspect ratio of view is smaller than 16:10, "cut off" sides
+			tdble tdx = (1.0f-1.0f/rfactor)/2.0f;
+			tx1 += tdx;
+			tx2 -= tdx;
+		} else {
+			// Aspect ratio of view is larger than 16:10, "cut off" top and bottom
+			tdble tdy = (1.0f-rfactor)/2.0f;
+			ty1 += tdy;
+			ty2 -= tdy;
+		}
+
 		glDisable(GL_BLEND);
 		glEnable(GL_TEXTURE_2D);
 		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 		glColor3f(0.0, 0.0, 1.0);
 		glBindTexture(GL_TEXTURE_2D, GfuiScreen->bgImage);
 		glBegin(GL_QUADS);
-		glTexCoord2f(0.0, 0.0); glVertex3f(0.0, 0.0, 0.0);
-		glTexCoord2f(0.0, 1.0); glVertex3f(0.0, GfuiScreen->height, 0.0);
-		glTexCoord2f(1.0, 1.0); glVertex3f(GfuiScreen->width, GfuiScreen->height, 0.0);
-		glTexCoord2f(1.0, 0.0); glVertex3f(GfuiScreen->width, 0.0, 0.0);
+		glTexCoord2f(tx1, ty1); glVertex3f(0.0, 0.0, 0.0);
+		glTexCoord2f(tx1, ty2); glVertex3f(0.0, GfuiScreen->height, 0.0);
+		glTexCoord2f(tx2, ty2); glVertex3f(GfuiScreen->width, GfuiScreen->height, 0.0);
+		glTexCoord2f(tx2, ty1); glVertex3f(GfuiScreen->width, 0.0, 0.0);
 		glEnd();
 		glDisable(GL_TEXTURE_2D);
 		glEnable(GL_BLEND);
@@ -459,7 +476,7 @@ GfuiScreenActivate(void *screen)
 	glutMouseFunc(gfuiMouse);
 	glutMotionFunc(gfuiMotion);
 	glutPassiveMotionFunc(gfuiPassiveMotion);
-	glutIdleFunc(GfuiIdle);
+	glutIdleFunc((void(*)(void))NULL);
 	
 	if (GfuiScreen->onlyCallback == 0) {
 		if (GfuiScreen->hasFocus == NULL) {
