@@ -4,7 +4,7 @@
     created              : Fri Aug 13 22:29:56 CEST 1999
     copyright            : (C) 1999, 2004 by Eric Espie, Bernhard Wymann
     email                : torcs@free.fr
-    version              : $Id: screen.cpp,v 1.21 2006/10/29 17:00:53 berniw Exp $
+    version              : $Id: screen.cpp,v 1.23.2.1 2008/11/09 17:50:22 berniw Exp $
 ***************************************************************************/
 
 /***************************************************************************
@@ -19,12 +19,11 @@
 /** @file
     Screen management.
     @author	<a href=mailto:torcs@free.fr>Eric Espie</a>
-    @version	$Id: screen.cpp,v 1.21 2006/10/29 17:00:53 berniw Exp $
+    @version	$Id: screen.cpp,v 1.23.2.1 2008/11/09 17:50:22 berniw Exp $
     @ingroup	screen
 */
 
 #include <stdio.h>
-#include <string.h>
 #ifdef WIN32
 #include <windows.h>
 #endif
@@ -73,7 +72,7 @@ static int usedFG = 0;
 static char	**Res = NULL;
 static int nbRes = 0;
 #else // USE_RANDR_EXT
-static char	*Res[] = {"640x480", "800x600", "1024x768", "1152x768", "1152x864", "1200x854", "1200x960", "1280x1024", "1400x900", "1600x1200", "1680x1050", "320x200"};
+static char	*Res[] = {"640x480", "800x600", "1024x768", "1152x768", "1152x864", "1200x854", "1200x960", "1280x1024", "1400x900", "1600x1200", "1680x1050", "1920x1200", "320x200"};
 static const int nbRes = sizeof(Res) / sizeof(Res[0]);
 #endif // USE_RANDR_EXT
 
@@ -504,7 +503,15 @@ GfScrReinit(void * /* dummy */)
 		}
 	}
 	
-	retcode = execlp(cmd, cmd, (const char *)NULL);
+	char cmdarg[CMDSIZE];
+	snprintf(cmdarg, CMDSIZE, "\"%swtorcs.exe\"", GetLocalDir());
+	for (i = 0; i < CMDSIZE && cmdarg[i] != NULL; i++) {
+		if (cmdarg[i] == '/') {
+			cmdarg[i] = '\\';
+		}
+	}
+
+	retcode = execlp(cmd, cmdarg, (const char *)NULL);
 #else
     GfScrShutdown();
 
