@@ -4,7 +4,7 @@
     created              : Fri Aug 13 22:32:14 CEST 1999
     copyright            : (C) 1999 by Eric Espie                         
     email                : torcs@free.fr   
-    version              : $Id: tgfclient.h,v 1.3 2004/03/03 23:00:41 torcs Exp $                                  
+    version              : $Id: tgfclient.h,v 1.3.2.1 2008/08/16 14:12:08 berniw Exp $                                  
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,7 +19,7 @@
 /** @file   
     	The Gaming Framework API (client part).
     @author	<a href=mailto:torcs@free.fr>Eric Espie</a>
-    @version	$Id: tgfclient.h,v 1.3 2004/03/03 23:00:41 torcs Exp $
+    @version	$Id: tgfclient.h,v 1.3.2.1 2008/08/16 14:12:08 berniw Exp $
 */
 
 
@@ -181,9 +181,9 @@ extern int GfuiTitleCreate(void *scr, char *text, int maxlen);
 extern void GfuiLabelSetText(void *scr, int id, char *text);
 extern void GfuiLabelSetColor(void *scr, int id, float *color);
 
-extern void GfuiPrintString(char *text, float *fgColor, int font, int x, int y, int align);
+extern void GfuiPrintString(const char *text, float *fgColor, int font, int x, int y, int align);
 extern int  GfuiFontHeight(int font);
-extern int  GfuiFontWidth(int font, char *text);
+extern int  GfuiFontWidth(int font, const char *text);
 
 
 /* buttons */
