@@ -4,7 +4,7 @@
     created              : Wed Nov  1 21:33:22 CET 2000
     copyright            : (C) 2000 by Eric Espie
     email                : torcs@free.fr
-    version              : $Id: grutil.cpp,v 1.23 2005/08/05 09:48:30 berniw Exp $
+    version              : $Id: grutil.cpp,v 1.23.2.1 2008/11/09 17:50:22 berniw Exp $
 
 ***************************************************************************/
 
@@ -22,7 +22,6 @@
 #include <sys/types.h>
 #include <stdio.h>
 #include <ctype.h>
-#include <string.h>
 #ifdef WIN32
 #include <windows.h>
 #endif
@@ -111,12 +110,10 @@ bool grLoadPngTexture (const char *fname, ssgTextureInfo* info)
 
 	mipmap = doMipMap(fname, mipmap);
 
-#ifdef WIN32
 	GLubyte* tex2 = new GLubyte[w*h*4];
 	memcpy(tex2, tex, w*h*4);
 	free(tex);
 	tex = tex2;
-#endif // WIN32
 	
 	return grMakeMipMaps(tex, w, h, 4, mipmap);
 }
