@@ -4,7 +4,7 @@
     created              : Sun Mar 19 00:04:50 CET 2000
     copyright            : (C) 2000 by Eric Espie
     email                : torcs@free.fr
-    version              : $Id: aero.cpp,v 1.11 2005/02/01 18:54:02 berniw Exp $
+    version              : $Id: aero.cpp,v 1.14 2005/04/04 21:42:48 berniw Exp $
 
  ***************************************************************************/
 
@@ -53,35 +53,34 @@ SimAeroUpdate(tCar *car, tSituation *s)
     spdang = atan2(car->DynGCg.vel.y, car->DynGCg.vel.x);
 
     if (airSpeed > 10.0) {
-	for (i = 0; i < s->_ncars; i++) {
-	    if (i == car->carElt->index) {
-		continue;
-	    }
-	    otherCar = &(SimCarTable[i]);
-	    otherYaw = otherCar->DynGCg.pos.az;
-	    tmpsdpang = spdang - atan2(y - otherCar->DynGCg.pos.y, x - otherCar->DynGCg.pos.x);
-	    NORM_PI_PI(tmpsdpang);
-	    dyaw = yaw - otherYaw;
-	    NORM_PI_PI(dyaw);
-	    if ((otherCar->DynGC.vel.x > 10.0) &&
-		(fabs(dyaw) < 0.1396)) {
-		if (fabs(tmpsdpang) > 2.9671) {	    /* 10 degrees */
-		    /* behind another car */
-		    tmpas = 1.0 - exp(- 2.0 * DIST(x, y, otherCar->DynGCg.pos.x, otherCar->DynGCg.pos.y) /
-				      (otherCar->aero.Cd * otherCar->DynGC.vel.x));
-		    if (tmpas < dragK) {
-			dragK = tmpas;
-		    }
-		} else if (fabs(tmpsdpang) < 0.1396) {	    /* 8 degrees */
-		    /* before another car */
-		    tmpas = 1.0 - exp(- 4.0 * DIST(x, y, otherCar->DynGCg.pos.x, otherCar->DynGCg.pos.y) /
-				      (car->aero.Cd * car->DynGC.vel.x));
-		    if (tmpas < dragK) {
-			dragK = tmpas;
-		    }
+		for (i = 0; i < s->_ncars; i++) {
+			if (i == car->carElt->index) {
+				continue;
+			}
+			otherCar = &(SimCarTable[i]);
+			otherYaw = otherCar->DynGCg.pos.az;
+			tmpsdpang = spdang - atan2(y - otherCar->DynGCg.pos.y, x - otherCar->DynGCg.pos.x);
+			NORM_PI_PI(tmpsdpang);
+			dyaw = yaw - otherYaw;
+			NORM_PI_PI(dyaw);
+			if ((otherCar->DynGC.vel.x > 10.0) &&
+				(fabs(dyaw) < 0.1396)) {
+				if (fabs(tmpsdpang) > 2.9671) {	    /* 10 degrees */
+					/* behind another car */
+					tmpas = 1.0 - exp(- 2.0 * DIST(x, y, otherCar->DynGCg.pos.x, otherCar->DynGCg.pos.y) /
+									  (otherCar->aero.Cd * otherCar->DynGC.vel.x));
+					if (tmpas < dragK) {
+						dragK = tmpas;
+					}
+				} else if (fabs(tmpsdpang) < 0.1396) {	    /* 8 degrees */
+					/* before another car [not sure how much the drag should be reduced in this case. In no case it should be lowered more than 50% I think. - Christos] */
+					tmpas = 1.0 - 0.5f * exp(- 8.0 * DIST(x, y, otherCar->DynGCg.pos.x, otherCar->DynGCg.pos.y) / (car->aero.Cd * car->DynGC.vel.x));
+					if (tmpas < dragK) {
+						dragK = tmpas;
+					}
+				}
+			}
 		}
-	    }
-	}
     }
     car->airSpeed2 = airSpeed * airSpeed;
     tdble v2 = car->airSpeed2;
@@ -105,13 +104,10 @@ SimWingConfig(tCar *car, int index)
     tdble area;
 
     area              = GfParmGetNum(hdle, WingSect[index], PRM_WINGAREA, (char*)NULL, 0);
-	// we need also the angle
 	wing->angle       = GfParmGetNum(hdle, WingSect[index], PRM_WINGANGLE, (char*)NULL, 0);
     wing->staticPos.x = GfParmGetNum(hdle, WingSect[index], PRM_XPOS, (char*)NULL, 0);
     wing->staticPos.z = GfParmGetNum(hdle, WingSect[index], PRM_ZPOS, (char*)NULL, 0);
 
-	// wrong, because the angle of attack changes on jumps
-	//wing->Kx = -1.23 * area * sin(angle);
 	wing->Kx = -1.23 * area;
     wing->Kz = 4.0 * wing->Kx;
 
@@ -122,7 +118,7 @@ SimWingConfig(tCar *car, int index)
 
 
 void
-SimWingUpdate(tCar *car, int index)
+SimWingUpdate(tCar *car, int index, tSituation* s)
 {
     tWing  *wing = &(car->wing[index]);
     tdble vt2 = car->airSpeed2;
