@@ -3,7 +3,7 @@
     file        : ac3dgroup.cpp
     created     : Fri Apr 18 23:11:36 CEST 2003
     copyright   : (C) 2003 by Christophe Guionneau
-    version     : $Id: ac3dgroup.cpp,v 1.6 2004/01/18 16:04:47 torcs Exp $                                  
+    version     : $Id: ac3dgroup.cpp,v 1.6.2.1 2008/11/09 17:50:23 berniw Exp $                                  
 
  ***************************************************************************/
 
@@ -19,13 +19,13 @@
 /** @file   
     		
     @author	Christophe Guionneau
-    @version	$Id: ac3dgroup.cpp,v 1.6 2004/01/18 16:04:47 torcs Exp $
+    @version	$Id: ac3dgroup.cpp,v 1.6.2.1 2008/11/09 17:50:23 berniw Exp $
 */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
-#include <string.h>
+#include <cstring>
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
