@@ -4,7 +4,7 @@
     created              : Sat Dec 23 09:27:43 CET 2000
     copyright            : (C) 2000 by Eric Espie
     email                : torcs@free.fr
-    version              : $Id: maintrackgen.cpp,v 1.5 2005/07/19 19:55:56 berniw Exp $
+    version              : $Id: maintrackgen.cpp,v 1.5.2.2 2008/11/09 17:50:23 berniw Exp $
 
  ***************************************************************************/
 
@@ -20,12 +20,11 @@
 /** @file   
     		
     @author	<a href=mailto:torcs@free.fr>Eric Espie</a>
-    @version	$Id: maintrackgen.cpp,v 1.5 2005/07/19 19:55:56 berniw Exp $
+    @version	$Id: maintrackgen.cpp,v 1.5.2.2 2008/11/09 17:50:23 berniw Exp $
 */
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
-#include <string.h>
 #ifndef WIN32
 #include <unistd.h>
 #endif
@@ -90,7 +89,7 @@ static void Generate(void);
 
 void usage(void)
 {
-    fprintf(stderr, "Terrain generator for tracks $Revision: 1.5 $ \n");
+    fprintf(stderr, "Terrain generator for tracks $Revision: 1.5.2.2 $ \n");
     fprintf(stderr, "Usage: trackgen -c category -n name [-a] [-m] [-s] [-S] [-E <n> [-H <nb>]]\n");
     fprintf(stderr, "       -c category    : track category (road, oval, dirt...)\n");
     fprintf(stderr, "       -n name        : track name\n");
@@ -135,7 +134,7 @@ void init_args(int argc, char **argv)
 	    {"version", 1, 0, 0}
 	};
 
-	c = getopt_long(argc, argv, "hvn:c:azsSE:h:bBL:",
+	c = getopt_long(argc, argv, "hvn:c:azsSE:H:bBL:",
 			long_options, &option_index);
 	if (c == -1)
 	    break;
@@ -148,7 +147,7 @@ void init_args(int argc, char **argv)
 		exit(0);
 		break;
 	    case 1:
-		printf("Terrain generator for tracks $Revision: 1.5 $ \n");
+		printf("Terrain generator for tracks $Revision: 1.5.2.2 $ \n");
 		exit(0);
 		break;
 	    default:
@@ -164,7 +163,7 @@ void init_args(int argc, char **argv)
 	    HeightSteps = strtol(optarg, NULL, 0);
 	    break;
 	case 'v':
-	    printf("Terrain generator for tracks $Revision: 1.5 $ \n");
+	    printf("Terrain generator for tracks $Revision: 1.5.2.2 $ \n");
 	    exit(0);
 	    break;
 	case 'a':
@@ -215,7 +214,7 @@ void init_args(int argc, char **argv)
 	    exit(0);
 	}
 	if (strncmp(argv[i], "-v", 2) == 0) {
-	    printf("Terrain generator for tracks $Revision: 1.5 $ \n");
+	    printf("Terrain generator for tracks $Revision: 1.5.2.2 $ \n");
 	    exit(0);
 	}
 	if (strncmp(argv[i], "-a", 2) == 0) {
